TestFramesClick
open | ../tests/html/Frames.html |
selectFrame | mainFrame |
open | ../tests/html/test_click_page1.html |
verifyText | link | Click here for next page
clickAndWait | link |
verifyTitle | Click Page Target |
clickAndWait | previousPage |
verifyTitle | Click Page 1 |
clickAndWait | linkWithEnclosedImage |
verifyTitle | Click Page Target |
clickAndWait | previousPage |
clickAndWait | enclosedImage |
verifyTitle | Click Page Target |
clickAndWait | previousPage |
click | linkToAnchorOnThisPage |
verifyTitle | Click Page 1 |
click | linkWithOnclickReturnsFalse |
pause | 300 |
verifyTitle | Click Page 1 |
setTimeout | 5000 |
open | ../tests/html/test_click_page1.html |